# Sample run of the expression data.
# This is provided to indicate how the Rdata are used, but
# we are not responsible for any consequence of its use.
#
require(multtest)  # need to install this package from Bioconductor
require(Heatplus)  # need to install this package from Bioconductor

# ..........  Expression data: set proper working directory
setwd("P:/Analys/Microarray/breast/PublicData/")
load("StockMAS5.10v.Rdata")

# ..........Clinical data
load("survival.Rdata")
 stat5 = survdat$stat5
 brca5 = survdat$brca5

# ............... optimal genes
tstat = mt.teststat(StockMAS5.10v, stat5)
ord.z<- order(-tstat)
ng   = length(tstat)
k = 32
pick = c(ord.z[1:k],ord.z[(ng-k+1):ng])
  opt.gid = rownames(StockMAS5.10v)[pick]
  opt.AB = StockMAS5.10v.AB[pick]

# .............. clustering: training set
xdat = StockMAS5.10v[opt.gid,]
addvar = data.frame(Status.5yr= ifelse(stat5,1,0), 
                    BRCA.5yr = ifelse(brca5,1,0))
colnames(xdat)=NULL
rownames(xdat)=NULL
out.main=  heatmap_plus(xdat, addvar=addvar, 
       h=13, col=RGBColVec(64), equal=TRUE, reorder=c(F,T))
table(out.main$clus,stat5[out.main$colInd])  # for the table, unordered groups!

# ............................centroids for supervised clustering
xmean=NULL
for (i in 1:3){
  a = apply(xdat[,out.main$colInd][,out.main$clus==i], 1, mean)
  xmean = cbind(xmean,a)
}
xmean = xmean[,c(1,3,2)]   # order by risk group


