# Reference (with Supplementary Report):
# Yudi Pawitan, Judith Bjhle, Lukas Amler, Anna-Lena Borg, 
# Suszanne Egyhazi, Per Hall, Xia Han, Lars Holmberg, Fei Huang, 
# Sigrid Klaar, Edison T. Liu, Lance Miller, Hans Nordgren, 
# Alexander Ploner, Kerstin Sandelin, Peter Shaw, Johanna Smeds, 
# Lambert Skoog, Sara Wedrn, Jonas Bergh: 
# Gene expression profiling spares early breast cancer patients 
#  from adjuvant therapy - derived and validated in two population-
#  based cohorts. Breast Cancer Research 2005, 7:R953-R964. 
#
#
# This file is the R script for gene filtering used for the paper
# see the Supplementary Report of the paper in the BCR website
#
# .............................................Load raw data
load("StockMAS5-3-March-2006.Rdata")
#
# Gene filter:
# .......................................  10%-present filter
# .......................................  remove 136 control genes - AFFX***
# .......................................  remove 100 housekeeping genes from B chip
npat= ncol(StockMAS5.Exp)
pcall=0.1  # %present call
char4 = substr(rownames(StockMAS5.Exp),1,4)
pick = (StockMAS5.Cnt[,1] > pcall*npat) & !(char4 == 'AFFX') & !(char4 == '2000' & 
        StockMAS5.AB=='B')
  StockMAS5.10 = StockMAS5.Exp[pick,]
  StockMAS5.10.AB = StockMAS5.AB[pick]
# variability requirement:
# 	the 15th smallest and the 15th largest values have a minimum absolute 
#	difference of 1000 and a minimum fold difference of 3.	
  sortdat = apply(StockMAS5.10,1,sort)
  k = 15
  smallk = sortdat[k,]
  largek = sortdat[npat-k+1,]
  pick = exp(largek - smallk)>3 & (exp(largek)-exp(smallk))>1000
  sum(pick)
  table(StockMAS5.10.AB[pick])
# ..............................................  data set for analysis
  StockMAS5.10v = StockMAS5.10[pick,]
  StockMAS5.10v.AB = StockMAS5.10.AB[pick]
  save(StockMAS5.10v, StockMAS5.10v.AB,
     file='StockMAS5.10v.Rdata')


